@@ -20,6 +20,10 @@ private Q_SLOTS:
     void testToEntity();
     void testResolveEntities();
     void testEncodingNames();
+    void testUsAsciiEncoding_data();
+    void testUsAsciiEncoding();
+    void testUsAsciiDecoding_data();
+    void testUsAsciiDecoding();
 };
 
 #endif /* KCHARSETSTEST_H */
